%%
%% This is file `pdfdochex.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% eforms.dtx  (with options: `copyright,hexoctcodes')
%% 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% eForms package,                                      %%
%% Copyright (C) 2002-2021  D. P. Story                 %%
%%   dpstory@uakron.edu                                 %%
%%                                                      %%
%% This program can redistributed and/or modified under %%
%% the terms of the LaTeX Project Public License        %%
%% Distributed from CTAN archives in directory          %%
%% macros/latex/base/lppl.txt; either version 1 of the  %%
%% License, or (at your option) any later version.      %%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\HexGlyph{00}{efHxError}%{000}
\HexGlyph{01}{efHxError}%{001}
\HexGlyph{02}{efHxError}%{002}
\HexGlyph{03}{efHxError}%{003}
\HexGlyph{04}{efHxError}%{004}
\HexGlyph{05}{efHxError}%{005}
\HexGlyph{06}{efHxError}%{006}
\HexGlyph{07}{efHxError}%{006}
\HexGlyph{08}{efHxError}%{008}
\HexGlyph{09}{efHxError}%{009}
\HexGlyph{0A}{efHxError}%{012}
\HexGlyph{0B}{efHxError}%{013}
\HexGlyph{0C}{efHxError}%{014}
\HexGlyph{0D}{efHxError}%{015}
\HexGlyph{0E}{efHxError}%{016}
\HexGlyph{0F}{efHxError}%{017}
\HexGlyph{10}{efHxError}%{020}
\HexGlyph{11}{efHxError}%{021}
\HexGlyph{12}{efHxError}%{022}
\HexGlyph{13}{efHxError}%{023}
\HexGlyph{14}{efHxError}%{024}
\HexGlyph{15}{efHxError}%{025}
\HexGlyph{16}{efHxError}%{026}
\HexGlyph{17}{efHxError}%{027}
\HexGlyph{18}{030}% U+02D8 BREVE
\HexGlyph{19}{031}% U+02c7 CARON
\HexGlyph{1A}{032}% U+02c6 MODIFIER LETTER CIRCUMFLEX ACCENT
\HexGlyph{1B}{033}% U+02D9 DOT ABOVE
\HexGlyph{1C}{034}% U+02DD DOUBLE ACUTE ACCENT
\HexGlyph{1D}{035}% U+02DB OGONEK
\HexGlyph{1E}{036}% U+02DA RING ABOVEZ
\HexGlyph{1F}{037}% U+02DC SMALL TILDE
\HexGlyph{20}{040}% U+0020 SPACE
\HexGlyph{21}{041}% U+0021 EXCLAMATION MARK
\HexGlyph{22}{042}% U+0022 QUOTATION MARK
\HexGlyph{23}{043}% U+0022 NUMBER SIGN
\HexGlyph{24}{044}% U+0023 DOLLAR SIGN
\HexGlyph{25}{045}% U+002 PERCENT SIGN
\HexGlyph{26}{046}% U+0026 AMPERSAND
\HexGlyph{27}{047}% U+0027 APOSTROPHE
\HexGlyph{28}{050}% U+0028 LEFT PARENTHESIS
\HexGlyph{29}{051}% U+0029 RIGHT PAENTHESIS
\HexGlyph{2A}{052}% U+002A ASTERISK
\HexGlyph{2B}{053}% U+002B PLUS SIGN
\HexGlyph{2C}{054}% U+002C COMMA
\HexGlyph{2D}{055}% U+002D HYPHEN-MINUS
\HexGlyph{2E}{056}% U+002E FULL STOP
\HexGlyph{2F}{057}% U+002F SOLIDUS
\HexGlyph{30}{060}% U+0030 ZERO
\HexGlyph{31}{061}% U+0031 ONE
\HexGlyph{32}{062}% U+0032 TWO
\HexGlyph{33}{063}% U+0033 THREE
\HexGlyph{34}{064}% U+0034 FOUR
\HexGlyph{35}{065}% U+0035 FIVE
\HexGlyph{36}{066}% U+0036 SIX
\HexGlyph{37}{067}% U+0037 SEVEN
\HexGlyph{38}{070}% U+0038 EIGHT
\HexGlyph{39}{071}% U+0039 NINE
\HexGlyph{3A}{072}% U+003A COLON
\HexGlyph{3B}{073}% U+003B SEMICOLON
\HexGlyph{3C}{074}% U+003C LESS-THAN SIGN
\HexGlyph{3D}{075}% U+003D EQUALS SIGN
\HexGlyph{3E}{076}% U+003E GREATER-THAN SIGN
\HexGlyph{3F}{077}% U+003F QUESTION MARK
\HexGlyph{40}{100}% U+0040 COMMERCIAL AT
\HexGlyph{41}{101}% U+0041 CAPITAL LETTER A
\HexGlyph{42}{102}% U+0042 B
\HexGlyph{43}{103}% U+0043 C
\HexGlyph{44}{104}% U+0044 D
\HexGlyph{45}{105}% U+0045 E
\HexGlyph{46}{106}% U+0046 F
\HexGlyph{47}{107}% U+0047 G
\HexGlyph{48}{110}% U+0048 H
\HexGlyph{49}{111}% U+0049 I
\HexGlyph{4A}{112}% U+004A J
\HexGlyph{4B}{113}% U+004B K
\HexGlyph{4C}{114}% U+004C L
\HexGlyph{4D}{115}% U+004D M
\HexGlyph{4E}{116}% U+004E N
\HexGlyph{4F}{117}% U+004F O
\HexGlyph{50}{120}% U+0050 P
\HexGlyph{51}{121}% U+0051 Q
\HexGlyph{52}{122}% U+0052 R
\HexGlyph{53}{123}% U+0053 S
\HexGlyph{54}{124}% U+0054 T
\HexGlyph{55}{125}% U+0055 U
\HexGlyph{56}{126}% U+0056 V
\HexGlyph{57}{127}% U+0057 W
\HexGlyph{58}{130}% U+0058 X
\HexGlyph{59}{131}% U+0059 Y
\HexGlyph{5A}{132}% U+005A Z
\HexGlyph{5B}{133}% U+005B LEFT SQUARE BRACKET
\HexGlyph{5C}{134}% U+005C REVERSE SOLIDUS (BACKSLASH)
\HexGlyph{5D}{135}% U+005D RIGHT SQUARE BRACKET
\HexGlyph{5E}{136}% U+005E CIRCUMFLEX ACCENT
\HexGlyph{5F}{137}% U+005F LOW LINE
\HexGlyph{60}{140}% U+0060 GRAVE ACCENT
\HexGlyph{61}{141}% U+0061 LATIN SMALL LETTER a
\HexGlyph{62}{142}% U+0062 b
\HexGlyph{63}{143}% U+0063 c
\HexGlyph{64}{144}% U+0064 d
\HexGlyph{65}{145}% U+0065 e
\HexGlyph{66}{146}% U+0066 f
\HexGlyph{67}{147}% U+0067 g
\HexGlyph{68}{150}% U+0068 h
\HexGlyph{69}{151}% U+0069 i
\HexGlyph{6A}{152}% U+006A j
\HexGlyph{6B}{153}% U+006B k
\HexGlyph{6C}{154}% U+006C l
\HexGlyph{6D}{155}% U+006D m
\HexGlyph{6E}{156}% U+006E n
\HexGlyph{6F}{157}% U+006F o
\HexGlyph{70}{160}% U+0070 p
\HexGlyph{71}{161}% U+0071 q
\HexGlyph{72}{162}% U+0072 r
\HexGlyph{73}{163}% U+0073 s
\HexGlyph{74}{164}% U+0074 t
\HexGlyph{75}{165}% U+0075 u
\HexGlyph{76}{166}% U+0076 v
\HexGlyph{77}{167}% U+0077 w
\HexGlyph{78}{170}% U+0078 x
\HexGlyph{79}{171}% U+0079 y
\HexGlyph{7A}{172}% U+007A z
\HexGlyph{7B}{173}% U+007B LEFT CURLY BRACKET
\HexGlyph{7C}{174}% U+007C VERTICAL LINE
\HexGlyph{7D}{175}% U+007D RIGHT CURLY BRACKET
\HexGlyph{7E}{176}% U+007E TILDE
\HexGlyph{7F}{efHxError}% 177 UNDEFINED IN PDFDOCENC
\HexGlyph{80}{200}% U+2022 BULLET
\HexGlyph{81}{201}% U+2020 DAGGER
\HexGlyph{82}{202}% U+2021 DOUBLE DAGGER
\HexGlyph{83}{203}% U+2026 HORIZONTAL ELLIPSIS
\HexGlyph{84}{204}% U+2014 EM DASH
\HexGlyph{85}{205}% U+2013 EN DASH
\HexGlyph{86}{206}% U+0192 LATIN SMALL LETTER F WITH HOOK
\HexGlyph{87}{207}% U+2044 FRACTION SLASH
\HexGlyph{88}{210}% U+2039 SINGLE LEFT-POINTING ANGLE QUOTE MARK
\HexGlyph{89}{211}% U+203A SINGLE RIGHT-POINTING ANGLE QUOTE MARK
\HexGlyph{8A}{212}% U+2212 MINUS-SIGN
\HexGlyph{8B}{213}% U+2030 PER MILL SIGN
\HexGlyph{8C}{214}% U+201E DOUBLE LOW-9 QUOTE MARK
\HexGlyph{8D}{215}% U+201C LEFT DOUBLE QUOTE MARK
\HexGlyph{8E}{216}% U+201C RIGHT DOUBLE QUOTE MARK
\HexGlyph{8F}{217}% U+2018 LEFT SINGLE QUOTE MARK
\HexGlyph{90}{220}% U+2019 RIGHT SINGLE QUOTE MARK
\HexGlyph{91}{221}% U+201A SINGLE LOW-9 QUOTE MARK
\HexGlyph{92}{222}% U+2122 TRADE MARK SIGN
\HexGlyph{93}{223}% U+FB01 LATIN SMALL LIGATURE FI
\HexGlyph{94}{224}% U+FB02 LATIN SMALL LIGATURE FL
\HexGlyph{95}{225}% U+0141 LATIN CAPITAL LETTER L WITH STROKE
\HexGlyph{96}{226}% U+0152 LATIN CAPITAL LIGATURE OE
\HexGlyph{97}{227}% U+0160 LATIN CAPITAL LETTER S WITH CARON
\HexGlyph{98}{230}% U+0178 LATIN CAPITAL  LETTER Y WITH DIAERESIS
\HexGlyph{99}{231}% U+017D LATIN CAPITAL LETTER Z WITH CARON
\HexGlyph{9A}{232}% U+0131 LATIN SMALL LETTER DOTLESS I
\HexGlyph{9B}{233}% U+0142 LATIN SMALL LETTER L WITH STROKE
\HexGlyph{9C}{234}% U+0153 LATIN SMALL LIGATURE OE
\HexGlyph{9D}{235}% U+0161 LATIN SMALL LETTER S WITH CARON
\HexGlyph{9E}{236}% U+017E LATIN SMALL LETTER Z WITH CARON
\HexGlyph{9F}{efHxError}% 237 UNDEF IN PDFDOCENC
\HexGlyph{A0}{240}% U+20AC EURO SIGN
\HexGlyph{A1}{241}% U+00A1 INVERTED EXCLAMATION MARK
\HexGlyph{A2}{242}% U+00A2 CENT SIGN
\HexGlyph{A3}{243}% U+00A3 POUND SIGN
\HexGlyph{A4}{244}% U+00A4 CURRENCY SIGN
\HexGlyph{A5}{245}% U+00A5 YEN SIGN
\HexGlyph{A6}{246}% U+00A6 BROKEN BAR
\HexGlyph{A7}{247}% U+00A7 SECTION SIGN
\HexGlyph{A8}{250}% U+00A8 DIAERESIS
\HexGlyph{A9}{251}% U+00A9 COPYRIGHT SIGN
\HexGlyph{AA}{252}% U+00AA FEMININE ORDINAL INDICATOR
\HexGlyph{AB}{253}% U+00AB LEFT-POINTING DOUBLE ANGLE QUOTE MARK
\HexGlyph{AC}{254}% U+00AC NOT SIGN
\HexGlyph{AD}{efHxError}% 255 UNDEFINED IN PDFDOCENC
\HexGlyph{AE}{256}% U+00AE REGISTERED SIGN
\HexGlyph{AF}{257}% U+00AF MACRON
\HexGlyph{B0}{260}% U+00B0 DEGREE SIGN
\HexGlyph{B1}{261}% U+00B1 PLUS-MINUS SIGN
\HexGlyph{B2}{262}% U+00B2 SUPERSCRIPT 2
\HexGlyph{B3}{263}% U+00B3 SUPERSCRIPT 3
\HexGlyph{B4}{264}% U+00B4 ACUTE ACCENT
\HexGlyph{B5}{265}% U+00B5 MICRO SIGN
\HexGlyph{B6}{266}% U+00B6 PILCROW SIGN (PARAGRAPH SIGN)
\HexGlyph{B7}{267}% U+00B7 MIDDLE DOT
\HexGlyph{B8}{270}% U+00B8 CEDILLA
\HexGlyph{B9}{271}% U+00B9 SUPERSCRIPT ONE
\HexGlyph{BA}{272}% U+00BA MASCULINE ORDINAL INDICATOR
\HexGlyph{BB}{273}% U+00BB RIGHT-POINTING DOUBLE ANGLE QUOTE MARK
\HexGlyph{BC}{274}% U+00BC VULGAR FRACTION ONE QUARTER
\HexGlyph{BD}{275}% U+00BD VULGAR FRACTION ONE HALF
\HexGlyph{BE}{276}% U+00BE VULGAR FRACTION THREE QUARTERS
\HexGlyph{BF}{277}% U+00BF INVERTED QUESTION MARK
\HexGlyph{C0}{300}% U+00C0 LATIN CAPITAL LETTER A WITH GRAVE
\HexGlyph{C1}{301}% U+00C1 LATIN CAPITAL LETTER A WITH ACUTE
\HexGlyph{C2}{302}% U+00C2 LATIN CAPITAL LETTER A WITH CIRCUMFLEX
\HexGlyph{C3}{303}% U+00C3 LATIN CAPITAL LETTER A WITH TILDE
\HexGlyph{C4}{304}% U+00C4 LATIN CAPITAL LETTER A WITH DIAERESIS
\HexGlyph{C5}{305}% U+00C5 LATIN CAPITAL LETTER A WITH RING ABOVE
\HexGlyph{C6}{306}% U+00C6 LATIN CAPITAL LETTER AE
\HexGlyph{C7}{307}% U+00C7 LATIN CAPITAL LETTER C WITH CEDILLA
\HexGlyph{C8}{310}% U+00C8 LATIN CAPITAL LETTER E WITH GRAVE
\HexGlyph{C9}{311}% U+00C9 LATIN CAPITAL LETTER E WITH ACUTE
\HexGlyph{CA}{312}% U+00CA LATIN CAPITAL LETTER E WITH CIRCUMFLEX
\HexGlyph{CB}{313}% U+00CB LATIN CAPITAL LETTER E WITH DIAERESIS
\HexGlyph{CC}{314}% U+00CC LATIN CAPITAL LETTER I WITH GRAVE
\HexGlyph{CD}{315}% U+00CD LATIN CAPITAL LETTER I WITH ACUTE
\HexGlyph{CE}{316}% U+00CE LATIN CAPITAL LETTER I WITH CIRCUMFLEX
\HexGlyph{CF}{317}% U+00CF LATIN CAPITAL LETTER I WITH DIAERESIS
\HexGlyph{D0}{320}% U+00D0 LATIN CAPITAL LETTER ETH
\HexGlyph{D1}{321}% U+00D1 LATIN CAPITAL LETTER D WITH TILDE
\HexGlyph{D2}{322}% U+00D2 LATIN CAPITAL LETTER O WITH GRAVE
\HexGlyph{D3}{323}% U+00D3 LATIN CAPITAL LETTER O WITH ACUTE
\HexGlyph{D4}{324}% U+00D4 LATIN CAPITAL LETTER O WITH CIRCUMFLEX
\HexGlyph{D5}{325}% U+00D5 LATIN CAPITAL LETTER O WITH TILDE
\HexGlyph{D6}{326}% U+00D6 LATIN CAPITAL LETTER O WITH DIAERESIS
\HexGlyph{D7}{327}% U+00D7 MULTIPLICATION SIGN
\HexGlyph{D8}{330}% U+00D8 LATIN CAPITAL LETTER O WITH STROKE
\HexGlyph{D9}{331}% U+00D9 LATIN CAPITAL LETTER U WITH GRAVE
\HexGlyph{DA}{332}% U+00DA LATIN CAPITAL LETTER U WITH ACUTE
\HexGlyph{DB}{333}% U+00DB LATIN CAPITAL LETTER U WITH CIRCUMFLEX
\HexGlyph{DC}{334}% U+00DC LATIN CAPITAL LETTER U WITH DIAERESIS
\HexGlyph{DD}{335}% U+00DD LATIN CAPITAL LETTER Y WITH ACUTE
\HexGlyph{DE}{336}% U+00DE LATIN CAPITAL LETTER THORN
\HexGlyph{DF}{337}% U+00DF LATIN CAPITAL LETTER SHARP S (Eszett)
\HexGlyph{E0}{340}% U+00E0 LATIN SMALL LETTER A WITH GRAVE
\HexGlyph{E1}{341}% U+00E1 LATIN SMALL LETTER A WITH ACUTE
\HexGlyph{E2}{342}% U+00E2 LATIN SMALL LETTER A WITH CIRCUMFLEX
\HexGlyph{E3}{343}% U+00E3 LATIN SMALL LETTER A WITH TILDE
\HexGlyph{E4}{344}% U+00E4 LATIN SMALL LETTER A WITH DIAERESIS
\HexGlyph{E5}{345}% U+00E5 LATIN SMALL LETTER A WITH RING ABOVE
\HexGlyph{E6}{346}% U+00E6 LATIN SMALL LETTER AE
\HexGlyph{E7}{347}% U+00E7 LATIN SMALL LETTER C WITH CEDILLA
\HexGlyph{E8}{350}% U+00E8 LATIN SMALL LETTER E WITH GRAVE
\HexGlyph{E9}{351}% U+00E9 LATIN SMALL LETTER E WITH ACUTE
\HexGlyph{EA}{352}% U+00EA LATIN SMALL LETTER E WITH CIRCUMFLEX
\HexGlyph{EB}{353}% U+00EB LATIN SMALL LETTER E WITH DIAERESIS
\HexGlyph{EC}{354}% U+00EC LATIN SMALL LETTER I WITH GRAVE
\HexGlyph{ED}{355}% U+00ED LATIN SMALL LETTER I WITH ACUTE
\HexGlyph{EE}{356}% U+00EE LATIN SMALL LETTER I WITH CIRCUMFLEX
\HexGlyph{EF}{357}% U+00EF LATIN SMALL LETTER I WITH DIAERESIS
\HexGlyph{F0}{360}% U+00F0 LATIN SMALL LETTER ETH
\HexGlyph{F1}{361}% U+00F1 LATIN SMALL LETTER N WITH TILDE
\HexGlyph{F2}{362}% U+00F2 LATIN SMALL LETTER O WITH GRAVE
\HexGlyph{F3}{363}% U+00F3 LATIN SMALL LETTER O WITH ACUTE
\HexGlyph{F4}{364}% U+00F4 LATIN SMALL LETTER O WITH CIRCUMFLEX
\HexGlyph{F5}{365}% U+00F5 LATIN SMALL LETTER O WITH DIAERESIS
\HexGlyph{F6}{366}% U+00F6 LATIN SMALL LETTER C WITH ETH
\HexGlyph{F7}{367}% U+00F7 DIVISION SIGN
\HexGlyph{F8}{270}% U+00F8 LATIN SMALL LETTER O WITH STROKE
\HexGlyph{F9}{271}% U+00F9 LATIN SMALL LETTER U WITH GRAVE
\HexGlyph{FA}{272}% U+00FA LATIN SMALL LETTER U WITH ACUTE
\HexGlyph{FB}{273}% U+00FB LATIN SMALL LETTER U WITH CIRCUMFLEX
\HexGlyph{FC}{374}% U+00FC LATIN SMALL LETTER U WITH DIAERESIS
\HexGlyph{FD}{375}% U+00FD LATIN SMALL LETTER Y WITH ACUTE
\HexGlyph{FE}{376}% U+00FE LATIN SMALL LETTER C THORN
\HexGlyph{FF}{377}% U+00FF LATIN SMALL LETTER Y WITH DIAERESIS
\endinput
%%
%% End of file `pdfdochex.def'.
