%%
%% This is file `altadbfncs.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% insdljs.dtx  (with options: `copyright,altadbfncs')
%% 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% insdljs.sty package,                                 %%
%% Copyright (C) 2001-2021  D. P. Story                 %%
%%   dpstory@uakron.edu                                 %%
%%                                                      %%
%% This program can redistributed and/or modified under %%
%% the terms of the LaTeX Project Public License        %%
%% Distributed from CTAN archives in directory          %%
%% macros/latex/base/lppl.txt; either version 1 of the  %%
%% License, or (at your option) any later version.      %%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\begin{insDLJS}{altadbfncs}{indljs: Alternate Adobe Function Names}
var EFNumber_Keystroke=AFNumber_Keystroke;
var EFNumber_Format=AFNumber_Format;
var EFPercent_Keystroke=AFPercent_Keystroke;
var EFPercent_Format=AFPercent_Format;
var EFDate_Format=AFDate_Format;
var EFDate_Keystroke=AFDate_Keystroke;
var EFDate_FormatEx=AFDate_FormatEx;
var EFTime_Keystroke=AFTime_Keystroke;
var EFTime_Format=AFTime_Format;
var EFTime_FormatEx=AFTime_FormatEx;
var EFDate_KeystrokeEx=AFDate_KeystrokeEx;
var EFSpecial_Keystroke=AFSpecial_Keystroke;
var EFSpecial_Format=AFSpecial_Format;
var EFSpecial_KeystrokeEx=AFSpecial_KeystrokeEx;
var EFRange_Validate=AFRange_Validate;
var EFSimple_Calculate=AFSimple_Calculate;
var EFMergeChange=AFMergeChange;
\end{insDLJS}
\endinput
%%
%% End of file `altadbfncs.def'.
