%%
%% This is file `dljscc.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% insdljs.dtx  (with options: `copyright,cc4js')
%% 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% insdljs.sty package,                                 %%
%% Copyright (C) 2001-2021  D. P. Story                 %%
%%   dpstory@uakron.edu                                 %%
%%                                                      %%
%% This program can redistributed and/or modified under %%
%% the terms of the LaTeX Project Public License        %%
%% Distributed from CTAN archives in directory          %%
%% macros/latex/base/lppl.txt; either version 1 of the  %%
%% License, or (at your option) any later version.      %%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\def\r{\eqesc r\ckivspace}
\def\t{\eqesc t\ckivspace}
\def\n{\eqesc n\ckivspace}
\def\f{\eqesc f\ckivspace}
\def\v{\eqesc v\ckivspace}
\def\b{\eqesc b\ckivspace}
\def\B{\eqesc B\ckivspace}
\def\d{\eqesc d\ckivspace}
\def\D{\eqesc D\ckivspace}
\def\s{\eqesc s\ckivspace}
\def\S{\eqesc S\ckivspace}
\def\w{\eqesc w\ckivspace}
\def\W{\eqesc W\ckivspace}
\begingroup
\catcode`\:=12\relax
\dljstfor\dlhex:={AA}{AB}{AC}{AD}{AE}{AF}%
    {BA}{BB}{BC}{BD}{BE}{BF}{CA}{CB}{CC}{CD}{CE}{CF}%
    {DA}{DB}{DC}{DD}{DE}{DF}{EA}{EB}{EC}{ED}{EE}{EF}%
    {FA}{FB}{FC}{FD}{FE}{FF}\do{%
    \expandafter\xdef\csname x\dlhex\endcsname{\noexpand\eqesc x\dlhex}%
}
\endgroup
\def\u{\eqesc u\ckivspace}
\def\0{\eqesc0}
\def\1{\eqesc1}
\def\2{\eqesc2}
\def\3{\eqesc3}
\definebraces
\def\({\eqesc\eqesci(}
\def\){\eqesc\eqesci)}
\def\.{\eqesc.}
\def\/{\eqesc/}
\def\[{\eqesc[}
\def\]{\eqesc]}
\def\|{\eqesc|}
\def\+{\eqesc+}
\def\*{\eqesc*}
\def\-{\eqesc-}
\def\?{\eqesc?}
\def\${\eqesc$}
\def\^{\eqesc^}
\def\\{\eqesc\eqesc}
\def\'{\eqesc'}
\catcode`\"=12
\def\"{\eqesc"}
\catcode`\<=12
\def\<{\eqesc<}
\catcode`\>=12
\def\>{\eqesc>}
\catcode`\%=12
\def\%{%}
\catcode`\%=14
\catcode`\& = 12
\def\&{\eqesc&}
\endinput
%%
%% End of file `dljscc.def'.
