%%
%% This is file `epdftex.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% eforms.dtx  (with options: `copyright,epdftex')
%% 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% eForms package,                                      %%
%% Copyright (C) 2002-2021  D. P. Story                 %%
%%   dpstory@uakron.edu                                 %%
%%                                                      %%
%% This program can redistributed and/or modified under %%
%% the terms of the LaTeX Project Public License        %%
%% Distributed from CTAN archives in directory          %%
%% macros/latex/base/lppl.txt; either version 1 of the  %%
%% License, or (at your option) any later version.      %%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\def\noPeek#1#2{\global\pdfpageattr=\expandafter{\noPeekAction{#1}{#2}}}
\def\HyField@@AddToFields#1{%
  \HyField@AfterAuxOpen{%
    \if@filesw
      \write\@mainaux{%
        \string\HyField@AuxAddToFields{#1}}%
    \ifisCalculate\write\@mainaux{%
        \string\HyField@AuxAddToCoFields{}{#1}}\fi
    \fi
  }%
}%
\def\eq@choice@driver
{%
  \Hy@pdfstringtrue
  \ifx\@vertRotate\ef@One
    \let\W@temp\eq@rectW\edef\eq@rectW{\eq@rectH}%
    \edef\eq@rectH{\W@temp}\fi\centerWidget\eq@rectH
  \ifx\autoCenter\ef@n\eqcenterWidget=0pt\fi
  \hbox{\pdfstartlink user{\common@choiceCode}%
  \lower\eqcenterWidget\ef@Bbox{\eq@rectW}{\eq@rectH}\pdfendlink}%
  \HyField@AddToFields
  \endgroup
  \dl@restorespcs
}
\def\eq@Button@driver
{%
  \Hy@pdfstringtrue
  \ifx\eq@rectW\@empty\def\eq@rectW{\wd\eq@tmpbox}\ef@djXPD\fi
  \ifx\@vertRotate\ef@One
    \let\W@temp\eq@rectW\edef\eq@rectW{\eq@rectH}%
    \edef\eq@rectH{\W@temp}\fi\centerWidget\eq@rectH
  \ifx\autoCenter\ef@n\eqcenterWidget=0pt\fi
  \ifx\eq@rectW\@empty\def\eq@rectW{\wd\eq@tmpbox}\fi
  \hbox{\pdfstartlink user{\common@pushButtonCode}%
  \lower\eqcenterWidget\ef@Bbox{\eq@rectW}{\eq@rectH}\pdfendlink}%
  \HyField@AddToFields
  \endgroup
  \dl@restorespcs
}
\def\parentRef#1#2{\csarg\gdef{parent@#1}{#2 0 R}}
\def\ef@radioData#1#2{\expandafter
  \HyField@@AddToFields\expandafter{#2}%
  \immediate\write\@mainaux{\string\parentRef{#1}{#2}}}
\def\eq@Radio@driver{\Hy@pdfstringtrue
  \ifx\@vertRotate\ef@One
    \let\W@temp\eq@rectW\edef\eq@rectW{\eq@rectH}%
    \edef\eq@rectH{\W@temp}\fi\centerWidget\eq@rectH
  \ifx\autoCenter\ef@n\eqcenterWidget=0pt\fi
  \ifuseNewRadios
    \ifx\isRadioParent\ef@YES\expandafter
      \ifx\csname radio@\Fld@name\endcsname\relax\else
        \immediate\pdfobj{<< \radio@parent\space >>}%
        \ef@radioData{\Fld@name}{\the\pdflastobj}%
        \ifx\eq@V\@empty\else
            \csarg\xdef{value@\Fld@name}%
              {\@nameuse{OnVal@\Fld@name}}%
        \fi
      \fi
      \ifx\ef@multigroupradios\ef@YES
        \csarg\gdef{multigroup@\Fld@name}%
          {\let\ef@multigroupradios\ef@YES}%
      \else
        \csarg\gdef{multigroup@\Fld@name}%
          {\let\ef@multigroupradios\ef@NO}%
      \fi
      \ifx\isRadiosInUnison\ef@YES
        \csarg\gdef{uniradios@\Fld@name}%
          {\let\isRadiosInUnison\ef@YES}%
      \else
        \csarg\gdef{uniradios@\Fld@name}%
          {\let\isRadiosInUnison\ef@NO}%
      \fi
    \fi
  \fi
  \ifuseNewRadios\expandafter\ef@NewRadiosLateOpts\fi
  \ifx\eq@rectW\@empty\def\eq@rectW{\wd\eq@tmpbox}\fi
  \hbox{\pdfstartlink user{\common@RadioCode}%
  \lower\eqcenterWidget\ef@Bbox{\eq@rectW}{\eq@rectH}\pdfendlink}%
  \ifuseNewRadios
    \edef\x{\noexpand\g@addto@macro\noexpand
      \ef@KidsArray{\the\pdflastlink\space 0 R\space}}\x
    \csarg\xdef{kid@\Fld@name}{\ef@KidsArray}%
  \else
    \HyField@AddToFields
  \fi
  \endgroup
  \dl@restorespcs
}
\def\eq@Check@driver
{%
  \Hy@pdfstringtrue
  \ifx\@vertRotate\ef@One
    \let\W@temp\eq@rectW\edef\eq@rectW{\eq@rectH}%
    \edef\eq@rectH{\W@temp}\fi\centerWidget\eq@rectH
  \ifx\autoCenter\ef@n\eqcenterWidget=0pt\fi
  \ifx\eq@rectW\@empty\def\eq@rectW{\wd\eq@tmpbox}\fi
  \hbox{\pdfstartlink user{\common@CheckCode}%
  \lower\eqcenterWidget\ef@Bbox{\eq@rectW}{\eq@rectH}\pdfendlink}%
  \HyField@AddToFields
  \endgroup
  \dl@restorespcs
}
\def\eq@l@check@driver
{%
  \pdfstartlink user{\common@CheckCode}%
  \makebox[\eq@tmpdima]{\phantom{\link@@Content}}%
  \pdfendlink\HyField@AddToFields\endgroup
  \dl@restorespcs
}
\def\eq@TextField{\Hy@pdfstringtrue
  \ifx\@vertRotate\ef@One
    \let\W@temp\eq@rectW\edef\eq@rectW{\eq@rectH}%
    \edef\eq@rectH{\W@temp}\fi\centerWidget\eq@rectH
  \ifx\autoCenter\ef@n\eqcenterWidget=0pt\fi
  \leavevmode
  \hbox{\pdfstartlink user{\common@TextFieldCode}%
  \lower\eqcenterWidget\ef@Bbox{\eq@rectW}{\eq@rectH}\pdfendlink}%
  \HyField@AddToFields
  \endgroup
  \dl@restorespcs
}
\def\eq@SigField{\Hy@pdfstringtrue
  \ifx\@vertRotate\ef@One
    \let\W@temp\eq@rectW\edef\eq@rectW{\eq@rectH}%
    \edef\eq@rectH{\W@temp}\fi\centerWidget\eq@rectH
  \ifx\autoCenter\ef@n\eqcenterWidget=0pt\fi
  \leavevmode\hbox{\pdfstartlink user{\common@SigFieldCode}%
  \lower\eqcenterWidget\ef@Bbox{\eq@rectW}{\eq@rectH}\pdfendlink}%
  \HyField@AddToFields
  \endgroup
  \dl@restorespcs
}
\def\setLink@driver
{%
  \@eqBS{}%
  \leavevmode\pdfstartlink
  attr {\eq@Border}%
  user{/Subtype/Link \common@LinkCode}%
  \Hy@colorlink{\@linkcolor}\link@@Box
  \close@pdflink
  \endgroup
  \dl@restorespcs
}
\def\ef@setTabOrder{\ifx\ef@taborder\@empty\else
  \edef\ef@tmp@toks{\the\pdfpageattr\space/Tabs/\ef@taborder}%
  \global\pdfpageattr=\expandafter{\ef@tmp@toks}%
  \fi\endgroup
}
\endinput
%%
%% End of file `epdftex.def'.
