%%
%% This is file `rbmintrvl.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% exerquiz.dtx  (with options: `copyright,rbmIntrvl')
%% 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Exerquiz.sty package,                                %%
%% Copyright (C) 1999-2021  D. P. Story                 %%
%%   dpstory@uakron.edu                                 %%
%%                                                      %%
%% This program can redistributed and/or modified under %%
%% the terms of the LaTeX Project Public License        %%
%% Distributed from CTAN archives in directory          %%
%% macros/latex/base/lppl.txt; either version 1 of the  %%
%% License, or (at your option) any later version.      %%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\def\c@lcEPInfo[#1,#2]{%
  \setlength{\eflength}{(#1pt+#2pt)/2}%
  \edef\intrCAns{\strip@pt\eflength}%
  \setlength{\eflength}{(#2pt-#1pt)/2}%
    \edef\intrPrec{\strip@pt\eflength}%
}
\newcommand{\rbmIntrvl}[1]{\c@lcEPInfo#1\RespBoxMath}
\endinput
%%
%% End of file `rbmintrvl.def'.
