%%
%% This is file `eqcat.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% exerquiz.dtx  (with options: `copyright,eqcat')
%% 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Exerquiz.sty package,                                %%
%% Copyright (C) 1999-2021  D. P. Story                 %%
%%   dpstory@uakron.edu                                 %%
%%                                                      %%
%% This program can redistributed and/or modified under %%
%% the terms of the LaTeX Project Public License        %%
%% Distributed from CTAN archives in directory          %%
%% macros/latex/base/lppl.txt; either version 1 of the  %%
%% License, or (at your option) any later version.      %%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\ProvidesFile{eqcat.def}
%%%%%%%%%%%%%%%%%%% eqcat.def %%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Foreign language support for the exerquiz package.  %%
%% Name of translator: Ramon Ballester                 %%
%% e-mail address: ramon.ballester@udg.es              %%
%% Language:  (catalan)                                %%
%%                                                     %%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\renewcommand\exlabel{Exercici}
\renewcommand\exlabelsol{\exlabel}

\renewcommand\exsectitle{Solucions als \exlabel s}
\renewcommand\exsecrunhead{\exsectitle} %% change to @ form

\renewcommand{\eq@exsolafterDefault}{\textit{Soluci\'o}:}

\renewcommand\eq@sqslsectitle{Solucions als Tests}
\renewcommand\sqslsectitle{\eq@sqslsectitle}

\renewcommand\eq@sqslsecrunhead{Solucions als Tests}
\renewcommand\sqslsecrunhead{\eq@sqslsecrunhead}

\renewcommand\eq@sqsllabel{%
   \string\textbf{Soluci\protect\'{o} al Test:}}
\renewcommand\sqsllabel{\eq@sqsllabel}

\renewcommand\sqsolafter{\textit{Soluci\'o}:}

\renewcommand\eq@sqlabel{\textcolor{red}{Test.}}
\renewcommand\sqlabel{\eq@sqlabel}

\renewcommand\eq@sqslrtnlabel{Final del Test}
\renewcommand\sqslrtnlabel{\eq@sqslrtnlabel}

\renewcommand\eqsqrtmsg{"Correcte!"}
\renewcommand\eqsqwgmsg{"Incorrecte!"}

\renewcommand\eq@bqlabel{Inici del Test}
\renewcommand\bqlabel{\eq@bqlabel}
\renewcommand\eq@bqlabelISO{\eq@bqlabel}
\renewcommand\bqlabelISO{\eq@bqlabel}

\renewcommand\eq@eqlabel{Final del Test}
\renewcommand\eqlabel{\eq@eqlabel}
\renewcommand\eq@Score{Punts:}\renewcommand\eq@OutOf{de}
\renewcommand\eqInitQuizMsg{"Has d'iniciar el Test!
    Prem sobre "+msg+"."}
\renewcommand\eqMadeChoice{%
    "Ja has elegit una resposta.
     La teva resposta ha estat ("+Responses[probno]+").
     Vols canviar--la?"}
\renewcommand\eq@local@CA{Correctes}
\renewcommand\eq@local@RC{Les meves Respostes!}
\renewcommand\eq@local@AC{Si us plau!}
\dlJSStr*[noquotes]{\limSelWarningMsg}{"Per a aquesta pregunta,
  se li permet fer com a m\`{a}xim  "
  + n + " seleccions."}
\endinput
%%
%% End of file `eqcat.def'.
